设置文件导入代理

文件导入代理是在任何计算机上运行的命令行应用程序,其充当从受监视文件系统位置(例如文件夹或网络驱动器)导入内容的源。该代理监视并捕获此位置中的内容,然后根据过程中定义的规则将其馈送到导入处理器以进行进一步处理和路由。

仅当您的源是受监视文件夹(不是受监视电子邮件账户)时,才需要在本地计算机上安装并运行文件导入代理。可以使用 Capture 命令行实用程序帮助您注册服务器、配置导入作业以及列出它们。

下载并安装文件导入代理

从受监视文件夹中导入文件之前,需要在本地计算机上安装文件导入代理。

系统要求

文件导入代理为 Java 应用程序,其需要 Oracle JDK 版本 8u251 或安装此应用程序时提供的最新版本。文件导入代理与 Windows、Linux 和 Mac 兼容(请参见Oracle JDK 8 和 JRE 8 认证的系统配置)。

要下载并安装文件导入代理,请执行以下操作:
  1. 登录到 Oracle Content Management Web 界面,然后单击左侧导航面板中的捕获(在管理下)。如果您看不到此选项,表明您没有所需的访问权限。
  2. 在“内容捕获过程”页的下载下,单击 Oracle Content Capture 文件导入代理,将 capture-agent.zip 文件下载到本地计算机上。
  3. 提取 ZIP 文件。
  4. 必须将 <agent directory>\bin 添加到 PATH。代理目录是提取 capture-agent.zip 的文件夹。也可以将 CAPTURE_HOME 环境变量设置为提取的目录,并将 $CAPTURE_HOME\bin 添加到 PATH。
    在 Mac 上:
    sudo ln -s <agent directory>/bin/capture /usr/local/bin/capture

    在 Windows 上:

    运行 SystemPropertiesAdvanced.exe 文件,编辑环境变量,然后将 <agent directory>\bin 添加到 PATH 变量中。

  5. 将 CAPTURE_JAVA_HOME 变量设置为有效的 JDK 位置,要么作为环境变量,要么在 <agent directory>/conf/agent.properties 文件中。

为文件导入代理创建 Oracle Identity Cloud Service (IDCS) 应用程序

文件导入代理与 Oracle Content Management 交互以检索导入作业配置并上载文件。该过程通过调用 RESTful Web 服务来实现。API 受 OAuth 保护,因此文件导入代理需要 OAuth 令牌。IDCS 应用程序允许文件导入代理生成这些令牌。

要创建 IDCS 应用程序,请执行以下操作:
  1. 登录到我的服务仪表盘。
  2. 单击身份云。
  3. 复制服务实例 URL。通过该 URL,您可以访问 Oracle Content Management 实例。也就是说,您将在安装服务器后使用该 URL 来注册服务器。
  4. 在 Identity Cloud Service 控制台中,展开导航抽屉,然后单击应用程序。
  5. 单击添加。
  6. 在添加应用程序页中,单击机密应用程序。
  7. 在添加机密应用程序窗口的应用程序详细信息窗格中,输入应用程序的名称,然后单击下一步。
  8. 选择立即将此应用程序配置为客户端。
  9. 在授权下,选择资源所有者和 JWT 断言。
  10. 在令牌发布策略下,选择授权资源中的全部,然后单击下一步。
  11. 在资源选项卡上,接受默认值,然后单击下一步。
  12. 在 Web 层策略选项卡上,接受默认值,然后单击下一步。
  13. 在授权选项卡上,单击默认值,然后单击下一步。
  14. 单击完成。
    复制客户端 ID 和客户端密钥。使用 Capture 命令行实用程序注册服务器时,将需要它们。
  15. 在配置选项卡上,展开客户端配置。
  16. 向下滚动到令牌发布策略部分,然后单击添加范围。
  17. 在选择范围对话框中,找到 Oracle Content Management 实例,然后单击 >。
  18. 使用 /urn:opc:... 命令选择具有 URL 的范围,然后单击添加。
  19. 复制范围 URL。使用 Capture 命令行实用程序注册服务器时,将需要它。
  20. 单击保存,然后单击激活。

您已成功创建 IDCS 应用程序。现在可以继续使用 Capture 命令行实用程序注册服务器。

将 Oracle Content Management 注册到文件导入代理

必须将您的 Oracle Content Management 实例注册到 Capture 命令行实用程序,以便该实用程序知道使用 Oracle Content Management 实例配置了哪些导入作业,并可以将文件上载到此实例。

要注册 Oracle Content Management,请执行以下操作:
  1. 下载并安装文件导入代理(如果您的计算机上尚未安装该实用程序)。
  2. 在您的 Windows、Linux 或 Mac 操作系统上运行以下命令:
    $ capture register-server <NAME> --endpoint https://<oracle content management instance name>.oraclecloud.com -u username -p 'password' --idcsurl https://<server name>.identity.oraclecloud.com/oauth2/v1/token --clientid sampleid --clientsecret sample-secret --scope https://<server name>:<port number>/urn:opc:cec:all
    
    • Oracle Content Management 实例 URL:<oracle content management instance name>.oraclecloud.com

    • 您的 Oracle Content Management 实例 URL 的用户名和密码。

      注:

      为了减轻潜在的安全威胁,请考虑创建一个特定于文件导入代理的用户,仅为该用户分配所需过程的 Content Capture 角色或权限。
    • 身份服务实例 URL:https://<server name>.identity.oraclecloud.com/oauth2/v1/token(您在创建 IDCS 应用程序时复制了它的值。)

    • 客户端 ID:sampleid(您在创建 IDCS 应用程序时复制了它的值。)

    • 客户端密钥:sample-secret(您在创建 IDCS 应用程序时复制了它的值。)

    • 范围 URL:https://<server name>:<port number>/urn:opc:cec:all(您在创建 IDCS 应用程序时复制了它的值。)

  3. 通过运行以下命令列出导入作业来测试您的连接:
    $ capture list-import-jobs
    

    此时会显示在指定的 Oracle Content Management 实例上的内容捕获过程中配置的所有文件夹和文件列表导入作业的列表。

注册 Oracle Content Management 并配置导入作业后,配置从文件夹导入文件或配置列表文件导入。

使用 Capture 命令行实用程序

capture 命令行实用程序允许您配置“文件导入代理”,以便该代理可以将文档导入 Oracle Content Management 资料档案库中。它提供了使用和管理“文件导入代理”的命令。

------------------------
capture
------------------------
usage : capture <command> [options]
Run capture <command> -h' to get the detailed help for the command.
Commands:  
capture create-encryption-key <file>     Create an encryption key to encrypt/decrypt password for servers.                       [alias:   cek]  
capture register-server <name>           Registers a CEC server                                                                  [alias:   rs]  
capture list-servers                     Lists registered servers                                                                [alias:   ls]  
capture list-import-jobs                 Lists all Import Jobs from server                                                       [alias:  lij]  
capture configure-import-job             Configures import job. Set Import Folder path. Enable or disable.                       [alias:  cij] 
capture trigger-import-job               Forces import job processing.                                                           [alias:  tij]
capture refresh-config                   Refresh configuration from server.                                                      [alias:   rc]
capture list-procedures                  Displays capture procedures.                                                            [alias:   lp]  
capture register-database <name>         Registers external database.                                                            [alias:   rd]  
capture deregister-database              Deregister previously registered database.                                              [alias:   dd]  
capture list-databases                   Displays registered databases and tables.                                               [alias:   ld]  
capture register-table                   Registers tables in a database.                                                         [alias:   rt]  
capture deregister-table                 Deregister previously registered table.                                                 [alias:   dt]
capture list-table-sync-jobs             Lists all Asset Sync Jobs from server.                                                  [alias: ltsj]
capture trigger-table-sync               Force table / asset synchronization.                                                    [alias:  tts]
capture start                            Starts import agent                                                                     [alias:    s]  
capture stop                             Stops import agent                                                                      [alias:    x]  
capture status                           Shows import agent status                                                               [alias:   st]  
capture help                             Shows this message                                                                      [alias:    h]

-----------------------------
capture create-encryption-key
-----------------------------
usage: create-encryption-key <file> [-h]
Create an encryption key to encrypt/decrypt password for servers and save to <file>.
Options: 
-h,--help   Show help
Example:  
capture create-encryption-key ~/.ceckey                      Create encryption key and save to file ~/.ceckey
------------------------
capture register-server
------------------------
usage: capture register-server <name> -e <endpoint> -u <user> -p <password> [-k <key>] [-i <idcsurl>] [-c <clientid>] [-s <clientsecret>] [-o <scope>] [-m <timeout>] [-h]
Registers a CEC server. Specify -e <endpoint> for the server URL. Specify -u <user> and -p <password> for connecting to the server. Optionally specify -k <key> to encrypt the password.
Optionally specify <idcsurl>, <clientid>, <clientsecret> and <scope> for integration with IDCS app.
Options: 
-e,--endpoint <endpoint>           Server endpoint 
-u,--user <user>                   User name 
-p,--password <password>           Password 
-k,--key <key>                     The key file used to encrypt the password 
-i,--idcsurl <idcsurl>             Oracle Identity Cloud Service Instance URL 
-c,--clientid <clientid>           Client ID 
-s,--clientsecret <clientsecret>   Client secret 
-o,--scope <scope>                 Scope -m,--timeout <timeout>             Timeout in millisecond when try to login to the server. Defaults to 30000ms 
-h,--help                          Show help
Examples:  
capture register-server server1 -e http://server1.com -u user1 -p password1 -i                         The server is a tenant on Oracle Public cloud  
http://idcs1.com -c clientid -s clientsecret -o https://primary-audience-and-scope  
capture register-server server1 -e http://server1.com -u user1 -p password1                            The server is a tenant on Oracle Public cloud  
capture register-server server1 -e http://server1.com -u user1 -p password1 -m 60000                   The timeout is set to 60 seconds  
capture register-server server1 -e http://server1.com -u user1 -p password1 -k ~/.mykey                The password will be encrypted
------------------------
capture list-servers
------------------------
usage: capture list-servers [-u <user>] [-f <pattern>] [-h]
Lists registered CEC servers. Optionally specify -u <user> and -f <pattern> to filter results based on user or server name.
Options: -u,--user <user>         User name 
-f,--pattern <pattern>   String to search in server name 
-h,--help                Show help
Examples:  
capture list-servers                                         Lists all registered servers  
capture list-servers -u user1                                Lists all registered servers linked to user 'user1'  
capture list-servers -f demo                                 Lists all registered servers whose name contains 'demo'
------------------------
capture list-import-jobs
------------------------
usage: capture list-import-jobs [-f] [-l] [-h]
Lists all Import Jobs from server. Optionally specify -f and -l to show only folder or list file import jobs.
Options: 
-f,--folder     Display only folder import jobs 
-l,--listfile   Display only list file import jobs 
-h,--help       Show help
Examples:  
capture list-import-jobs                                         Lists all import jobs  
capture list-import-jobs -f                                      Lists all folder import jobs  
capture list-import-jobs -l                                      Lists all list file import jobs
-----------------------------
capture configure-import-job
-----------------------------
usage: capture configure-import-job -s <server> [-i <import>] [-p <path>] [-e] [-E] [-d] [-D] [-h]
Configures the import job.  Specify -s <server> -i <importjobid> to select the server and import job. Optionally specify -p <path> to set the import folder path. 
Optionally specify -d to disable import job and -e to enable import job
Options: 
-s,--server <server>   Set server name associated with import job 
-i,--import <import>   Set Import Job Id 
-p,--path <path>       Set Local Import Folder Path 
-e,--enable            Enables specific import job 
-E,--enable-all        Enables all import jobs 
-d,--disable           Disables specific import job 
-D,--disable-all       Disables all import job 
-h,--help              Show help
Examples:  
capture configure-import-job -s prod -i import_id -p /Users/user1/data/      Sets the import directory  
capture configure-import-job -s prod -i import_id -e                         Enables a specific import job  
capture configure-import-job -s prod -D                                      Disables all import jobs  
capture configure-import-job -s prod -i import_id -d                         Disables a specific import job
------------------------
capture trigger-import-job
------------------------
usage: capture trigger-import-job -s <server> -i <import> [-h] 
Forces import job processing.  
Options: 
-s,--server <server>   Set server name associated with import job 
-i,--import <import>   Set Import Job Id 
-h,--help              Show help 
Examples:  capture trigger-import-job --server production --import xx-job-id-xx           Forces processing of specified import job
------------------------
capture refresh-config
------------------------
usage: capture refresh-config [-s <server>] [-h] Refresh configuration from server. 
Optionally specify -s to only refresh config for selected server. 
Options: 
-s,--server <server>   Specify the server 
-h,--help              Show help 
Examples:  
capture refresh-config                       Force refresh configuration for all servers  
capture refresh-config -s production         Force refresh configuration from specified server                        
------------------------
capture list-procedures
------------------------
usage: capture list-procedures -s <server> [-h] 
Lists capture procedures. Must specify -s <server> to select a server. 
Options: 
-s,--server <server>   Specify the server 
-h,--help              Show help 
Examples:  capture list-procedures -s ocetest                           Lists all capture procedures available for current user
------------------------
capture register-database
------------------------
usage: capture register-database <name> -s <server> -w <procedure> -c <connection> -u <user> -p <password> [-a] [-h] 
Registers on-prem database with Capture. Specify -c <connection> for the connection URL, -u <user> and -p <password> for connecting to the server. 
Options: 
-s,--server <server>           Specify the server 
-w,--procedure <procedure>     Set procedure to be associated with database 
-c,--connection <connection>   Database connection url 
-u,--user <user>               Database User name 
-p,--password <password>       Database Password 
-a,--attach                    Attach existing database 
-h,--help                      Show help 
Examples:  
capture register-database ebsdb -s server1 -w 1 -c jdbc:oracle:thin:@//host:port/service -u user1 -p pass         Register ebsdb with server1
------------------------
capture deregister-database
------------------------
usage: capture deregister-database  -s <server> -w <procedure> -d <database> [-e] [-h] 
Deregister previously registered database. Specify -s <server>, -w <procedure> and -d <database> to select the database. 
Options: 
-s,--server <server>         Specify the server 
-w,--procedure <procedure>   Procedure associated with database 
-d,--database <database>     Database to deregister 
-e,--detach                  Only detach 
-h,--help                    Show help 
Examples:  
capture deregister-database -s server1 -w 1 -d ebsdb                   Deregister VENDORS table from ebsdb database  
capture deregister-database -s server1 -w 1 -d ebsdb --detach          Detaches ebsdb database without deregistering it
------------------------
capture list-databases
------------------------
usage: capture list-databases -s <server> [-h] Lists registered databases and tables. Must specify -s <server> to select a server. 
Options: 
-s,--server <server>   Specify the server 
-h,--help              Show help 
Examples:  
capture list-databases -s ocetest     Lists all registered databased linked to server 'ocetest'  
------------------------
capture register-table
------------------------
usage: capture register-table -s <server> -w <procedure> -d <database> -t <table> [-m <schema>] [-h]
Registers table with Capture. Specify -s <server>, -w <procedure> and -d <database> to select the database. 
Options: 
-s,--server <server>         Specify the server 
-w,--procedure <procedure>   Specify the procedure 
-d,--database <database>     Specify the database 
-t,--table <table>           Table to sync 
-m,--schema <schema>         Override schema qualifier 
-h,--help                    Show help 
Examples:  
capture register-table -s server1 -w 1 -d ebsdb -t VENDORS                  Register VENDORS table from ebsdb database  
capture register-table -s server1 -w 1 -d ebsdb -t VENDORS -m SVR           Register VENDORS table from ebsdb database in SVR schema
------------------------
capture deregister-table
------------------------
usage: capture deregister-table -s <server> -w <procedure> -d <database> -t <table> [-m <schema>] [-h] 
Deregister table. Specify table details. 
Options: 
-s,--server <server>         Specify the server 
-w,--procedure <procedure>   Procedure associated with database 
-d,--database <database>     Specify the database 
-t,--table <table>           Table to sync 
-m,--schema <schema>         Override schema qualifier 
-h,--help                    Show help 
Examples:  capture deregister-table -s server1 -w 1 -d ebsdb -t VENDORS                      Deregister VENDORS table from ebsdb database      
------------------------
capture list-table-sync-jobs
------------------------
usage: capture list-table-sync-jobs [-r] [-h] Lists all Asset Sync Jobs from server. 
Options: 
-r,--refresh   Force refresh asset sync jobs from server 
-h,--help      Show help 
Examples:  
capture list-table-sync-jobs                                         Lists all asset sync jobs  
capture list-table-sync-jobs -r                                      Refresh asset sync jobs from server and list them
------------------------
capture trigger-table-sync
------------------------
usage: capture trigger-table-sync -s <server> -a <asset> [-h] 
Force table / asset synchronization.  
Options: 
-s,--server <server>   Set server name associated with table sync job 
-a,--asset <asset>     Set Asset Sync Job Id 
-h,--help              Show help 
Examples:  
capture trigger-table-sync -s production -i xx-123-sync-id-xx      Forces processing of asset synchronization job
------------------------
capture start
------------------------
usage: capture start [-h]
Starts capture agent. 
Options: 
-h,--help   Show help
Examples:  
capture start                                                Starts capture agent if not running
------------------------
capture stop
------------------------
usage: capture stop [-h]
Stops capture agent. 
Options: 
-h,--help   Show help
Examples:  
capture stop                                                 Stops capture agent if currently running
------------------------
capture status
------------------------
usage: capture status [-s <server>] [-i <import>] [-u <user>] [-m <machine>] [-l <limit>] [-d <duration>] [-c | -p]  [-h] 
Display capture agent status and activity.  
Options: 
-s,--server <server>       Set Server name 
-i,--import <import>       Set Import Job name 
-u,--user <user>           Set user name. Defaults to current user 
-m,--machine <machine>     Set host name. Defaults to current hostname 
-l,--limit <limit>         Set number of results to return. Defaults to 200 
-d,--duration <duration>   Set duration period in hours 
-c,--completed             Display only completed uploads 
-p,--pending               Display only pending uploads 
-h,--help                  Show help 
Examples:  
capture status                             Display capture agent status  
capture status -u user@example.com         Show upload activity for user : user@example.com  
capture status -i Invoices                 Show upload activity for Invoices import job  
capture status -m myhost.example.com       Show upload activity for a specific host / machine  
capture status -p                          Show uploads pending completion  
capture status -c                          Show completed uploads
------------------------
capture version
------------------------
usage: capture version [-h] 
Displays capture version details. 
Options: 
-h,--help    Show help 
Example:  
capture  version                  Display Capture Agent version